@@ -531,7 +531,7 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
 
   if (gdk_pointer_grab (widget->window, FALSE,
                         GDK_BUTTON_PRESS_MASK,
-                        FALSE, NULL,
+                        NULL, NULL,
                         gdk_event_get_time (event)) != GDK_GRAB_SUCCESS)
     {
       gdk_keyboard_ungrab (gdk_event_get_time (event));
@@ -582,9 +582,9 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
 }
 
 void
-egg_cell_renderer_keys_set_accelerator (EggCellRendererKeys *keys,
-                                        guint                keyval,
-                                        GdkModifierType      mask)
+egg_cell_renderer_keys_set_accelerator (EggCellRendererKeys    *keys,
+                                        guint                   keyval,
+                                        EggVirtualModifierType  mask)
 {
   char *text;
   gboolean changed;
@@ -624,9 +624,9 @@ egg_cell_renderer_keys_set_accelerator (EggCellRendererKeys *keys,
 }
 
 void
-egg_cell_renderer_keys_get_accelerator (EggCellRendererKeys *keys,
-                                        guint               *keyval,
-                                        GdkModifierType     *mask)
+egg_cell_renderer_keys_get_accelerator (EggCellRendererKeys     *keys,
+                                        guint                   *keyval,
+                                        EggVirtualModifierType  *mask)
 {
   g_return_if_fail (EGG_IS_CELL_RENDERER_KEYS (keys));
 
